Sharpen — Thumbor 7.0.0a1 documentation

# Sharpen

Usage: sharpen(sharpen_amount,sharpen_radius,luminance_only)

## Description

This filter enhances apparent sharpness of the image. It’s heavily based on Marco Rossini’s excellent Wavelet sharpen GIMP plugin. Check http://registry.gimp.org/node/9836 for details about how it work.

## Arguments

- `sharpen_amount` - Sharpen amount. Typical values are between \(0.0\) and \(10.0\).

- `sharpen_radius` - Sharpen radius. Typical values are between \(0.0\) and \(2.0\).

- `luminance_only` - Sharpen only luminance channel. Values can be `true` or `false`.

## Example 1

http://localhost:8888/unsafe/filters:sharpen(2,1.0,true)/http://videoprocessing.ucsd.edu/~stanleychan/research/pix/Blurred_foreman_0005.png

## Example 2

http://localhost:8888/unsafe/filters:sharpen(1.5,0.5,true)/http://images.cambridgeincolour.com/tutorials/sharpening_eagle2-original.jpg